@@ -1,5 +1,5 @@
 /*  Copyright (c) 2003-2007 Xfce Development Team
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -23,24 +23,18 @@
 
 G_BEGIN_DECLS
 
-const gchar *translate_desc (const gchar *);
+const gchar *translate_desc(const gchar *desc,
+                            gboolean nighttime);
 
-const gchar *translate_bard (const gchar *);
+const gchar *translate_moon_phase(const gchar *moon_phase);
 
-const gchar *translate_risk (const gchar *);
+/* these return a newly allocated string, that should be freed */
+gchar *translate_day(gint weekday);
 
-/* these return a newly alocted string, that should be freed */
-gchar *translate_lsup (const gchar *);
+gchar *translate_wind_direction(const gchar *wdir);
 
-gchar *translate_day (const gchar *);
-
-gchar *translate_wind_direction (const gchar *);
-
-gchar *translate_wind_speed (const gchar *, units);
-
-gchar *translate_time (const gchar *);
-
-gchar *translate_visibility (const gchar *, units);
+gchar *translate_wind_speed(const gchar *wspeed,
+                            unit_systems unit_system);
 
 G_END_DECLS
 
